# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "Also available in": "Şu dilde de mevcut",
    "Also available in:": "Şu dilde de mevcut:",
    "Archive": "Arşiv",
    "Categories": "Kategoriler",
    "LANGUAGE": "Türkçe",
    "More posts about %s": "%s ilgili diğer yazılar",
    "More posts about": " ilgili diğer yazılar",
    "Newer posts": "Daha yeni yazılar",
    "Next post": "Sonraki yazı",
    "No posts found.": "",
    "Nothing found.": "",
    "Older posts": "Daha eski yazılar",
    "Original site": "Orjinal web sayfası",
    "Posted": "Yayın tarihi",
    "Posted:": "Yayın tarihi:",
    "Posts about %s": "%s ile ilgili yazılar",
    "Posts for year %s": "%s yılındaki yazılar",
    "Posts for {month} {year}": "{month} {year} göre yazılar",
    "Previous post": "Önceki yazı",
    "Read in English": "Türkçe olarak oku",
    "Read more": "Devamını oku",
    "Source": "Kaynak",
    "Tags and Categories": "Etiketler ve Kategoriler",
    "Tags": "Etiketler",
    "old posts, page %d": "eski yazılar, sayfa %d",
    "page %d": "sayfa %d",
}
